@@ -15,7 +15,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from .utils import NamespacedClient, query_params, _make_path, SKIP_IN_PATH
+from .utils import SKIP_IN_PATH, NamespacedClient, _make_path, query_params
 
 
 class RollupClient(NamespacedClient):
@@ -24,7 +24,7 @@ class RollupClient(NamespacedClient):
         """
         Deletes an existing rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/rollup-delete-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/rollup-delete-job.html>`_
 
         .. warning::
 
@@ -45,7 +45,7 @@ class RollupClient(NamespacedClient):
         """
         Retrieves the configuration, stats, and status of rollup jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/rollup-get-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/rollup-get-job.html>`_
 
         .. warning::
 
@@ -65,7 +65,7 @@ class RollupClient(NamespacedClient):
         Returns the capabilities of any rollup jobs that have been configured for a
         specific index or index pattern.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/rollup-get-rollup-caps.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/rollup-get-rollup-caps.html>`_
 
         .. warning::
 
@@ -85,7 +85,7 @@ class RollupClient(NamespacedClient):
         Returns the rollup capabilities of all jobs inside of a rollup index (e.g. the
         index where rollup data is stored).
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/rollup-get-rollup-index-caps.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/rollup-get-rollup-index-caps.html>`_
 
         .. warning::
 
@@ -107,7 +107,7 @@ class RollupClient(NamespacedClient):
         """
         Creates a rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/rollup-put-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/rollup-put-job.html>`_
 
         .. warning::
 
@@ -134,7 +134,7 @@ class RollupClient(NamespacedClient):
         """
         Enables searching rolled-up data using the standard query DSL.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/rollup-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/rollup-search.html>`_
 
         .. warning::
 
@@ -167,7 +167,7 @@ class RollupClient(NamespacedClient):
         """
         Starts an existing, stopped rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/rollup-start-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/rollup-start-job.html>`_
 
         .. warning::
 
@@ -191,7 +191,7 @@ class RollupClient(NamespacedClient):
         """
         Stops an existing, started rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.10/rollup-stop-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/rollup-stop-job.html>`_
 
         .. warning::
 
@@ -214,3 +214,26 @@ class RollupClient(NamespacedClient):
             params=params,
             headers=headers,
         )
+
+    @query_params()
+    def rollup(self, index, rollup_index, body, params=None, headers=None):
+        """
+        Rollup an index
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/7.13/rollup-api.html>`_
+
+        :arg index: The index to roll up
+        :arg rollup_index: The name of the rollup index to create
+        :arg body: The rollup configuration
+        """
+        for param in (index, rollup_index, body):
+            if param in SKIP_IN_PATH:
+                raise ValueError("Empty value passed for a required argument.")
+
+        return self.transport.perform_request(
+            "POST",
+            _make_path(index, "_rollup", rollup_index),
+            params=params,
+            headers=headers,
+            body=body,
+        )
